#!/usr/bin/env python

#
# See __doc__ for an explanation of what this module does
#
# See __usage__ for an explanation of runtime arguments
#
# -Christopher Blunck
#


import unittest, os, sys

from constants import *


__doc__ = \
'''
Runs all of the tests in the directory specified by the user,
excluding those tests contained in the EXCLUDED_TESTS variable.  If no
directory is specified on the command line the current directory is
assumed
'''

__usage__ = \
'''
This module should be run from the command line
'''


def getTests(dir, prefix):
    """
    returns a [] containing names of test modules
    """
    
    tests = []
    for file in os.listdir(dir):
        if file.endswith('.pyc'):
            continue
        
        if file.find(prefix) == 0:
            name = file.replace('.py', '')
            if name not in EXCLUDED_TESTS:
                tests.append(name)

    return tests



def createSuite(dir=DEFAULT_TEST_DIRECTORY,
                excluding=EXCLUDED_TESTS,
                prefix=DEFAULT_TEST_MODULE_PREFIX):
    """
    creates a test suite from the modules in the directory provided.  assumes
    the tests are named TestCase
    """
    
    suite = unittest.TestSuite()
    for test in getTests(dir, prefix):
        mod = __import__(test, globals(), locals(), '*')
        suite.addTests(unittest.makeSuite(mod.TestCase)._tests)

    return suite
